# ifndef yyMakeSerial
# define yyMakeSerial

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"


extern void (* MakeSerial_Exit) ARGS ((void));

extern void MakeSerial ARGS ((tTree t));

extern void BeginMakeSerial ARGS ((void));
extern void CloseMakeSerial ARGS ((void));

# endif
